@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '1.20'; # VERSION
+our $DATE = '2015-07-08'; # DATE
+our $VERSION = '1.21'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -92,12 +92,15 @@ sub BUILD {
 
         $copts->{version}   = { $_t->('version'), };
         $copts->{help}      = { $_t->('help'), };
-        $copts->{format}    = {
-            $_t->('format'),
-            schema => ['str*' => in => $formats],
-        };
-        $copts->{json}      = { $_t->('json'), };
-        $copts->{naked_res} = { $_t->('naked_res'), };
+
+        unless ($self->skip_format) {
+            $copts->{format}    = {
+                $_t->('format'),
+                schema => ['str*' => in => $formats],
+            };
+            $copts->{json}      = { $_t->('json'), };
+            $copts->{naked_res} = { $_t->('naked_res'), };
+        }
         if ($self->subcommands) {
             $copts->{subcommands} = { $_t->('subcommands'), };
         }
@@ -577,7 +580,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.20 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-07.
+This document describes version 1.21 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-08.
 
 =head1 SYNOPSIS
 
